Linear Models
=============

.. currentmodule:: skcosmo.linear_model._base

Orthogonal Regression
#####################

.. autoclass:: OrthogonalRegression 

.. currentmodule:: skcosmo.linear_model._ridge

Ridge Regression with Two-fold Cross Validation
###############################################

.. autoclass:: RidgeRegression2FoldCV

PCovR
#####

Principal Covariates Regression is a linear model, see :ref:`PCovR-api`.
